/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 * filename: xfilesel.h                                                    *
 *                                                                         *
 * UTIL C-source: Medical Image Conversion Utility                         *
 *                                                                         *
 * purpose      : xfilesel.c header file                                   *
 *                                                                         *
 * project      : (X)MedCon by Erik Nolf                                   *
 *                                                                         *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* $Id: xfilesel.h,v 1.11 2004/04/06 11:32:02 enlf Exp $
 */

/*
   Copyright (C) 1997-2004 by Erik Nolf

   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
   Free Software Foundation; either version 2, or (at your option) any later
   version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
   Public License for more details.

   You should have received a copy of the GNU General Public License along
   with this program; if not, write to the Free Software Foundation, Inc.,
   59 Place - Suite 330, Boston, MA 02111-1307, USA.  */

#ifndef __XFILESEL_H__
#define __XFILESEL_H__

/****************************************************************************
                            F U N C T I O N S
****************************************************************************/
void XMdcFileSelOpenCallbackOk(GtkWidget *w, GtkWidget *fs);
void XMdcFileSelOpen(GtkWidget *widget, guint otype);
void XMdcFileSelSaveCreateFormatMenu(GtkWidget *fs, guint format);
void XMdcFileSelSaveCreateDefaultName(GtkWidget *fs);
void XMdcFileSelSaveCallbackFormatMenu(GtkWidget *fs, guint *selected_format);
void XMdcFileSelSaveCallbackAlias(GtkObject *fs, char *filename);
void XMdcFileSelSaveCallbackDefault(GtkObject *fs, char *filename);
void XMdcFileSelSaveCallbackOk(GtkWidget *w, GtkWidget *fs);
void XMdcFileSelSaveCallbackCancel(GtkWidget *w, GtkWidget *fs);
void XMdcFileSelSave(GtkWidget *widget, guint format);
void XMdcLutSelOpenCallbackOk(GtkWidget *w, GtkWidget *fs);
void XMdcLutSelOpen(GtkWidget *w, gpointer data);
void XMdcRawPredefSelSaveCallbackOk(GtkWidget *widget, GtkWidget *fs);
void XMdcRawPredefSelSave(GtkWidget *widget, gpointer data);
void XMdcRawPredefSelOpenCallbackOk(GtkWidget *w, GtkWidget *fs);
void XMdcRawPredefSelOpen(GtkWidget *widget, gpointer data);

#endif

